// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:wyatt_ui_components/wyatt_wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/buttons/cubit/button_cubit.dart';
import 'package:wyatt_ui_kit/src/core/helpers/theme_resolver.dart';
import 'package:wyatt_ui_kit/wyatt_ui_kit.dart';

class SymbolButtonThemeResolver extends ThemeResolver<SymbolButtonStyle,
    SymbolButtonThemeExtension, ButtonState> {
  const SymbolButtonThemeResolver({
    required this.computeExtensionValueFn,
    required this.customStyleFn,
  });

  @override
  SymbolButtonStyle computeDefaultValue(
    BuildContext context, {
    ButtonState? extra,
  }) =>
      SymbolButtonStyle(
        label: context.textTheme.labelLarge,
        dimension: context.buttonTheme.height,
        radius: (context.buttonTheme.shape is RoundedRectangleBorder)
            ? (context.buttonTheme.shape as RoundedRectangleBorder).borderRadius
            : null,
        padding: context.buttonTheme.padding,
        foregroundColors: MultiColor.single(context.colorScheme.onPrimary),
        backgroundColors: MultiColor.single(context.colorScheme.primary),
      );

  @override
  final SymbolButtonStyle? Function(
    BuildContext context,
    SymbolButtonStyle defaultValue,
    SymbolButtonThemeExtension themeExtension, {
    ButtonState? extra,
  }) computeExtensionValueFn;

  @override
  final SymbolButtonStyle? Function(
    BuildContext context, {
    ButtonState? extra,
  }) customStyleFn;
}
